@@ -339,6 +339,9 @@ class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin):
     def __repr__(self) -> str:
         return f"<{self.__class__.__name__}({self.name!r}, {self.lineno!r}, {self.endlineno!r})>"
 
+    def __len__(self) -> int:
+        return len(self.members) + sum(len(member) for member in self.members.values())
+
     @property
     def has_docstring(self) -> bool:
         """Tell if this object has a non-empty docstring."""
@@ -739,6 +742,9 @@ class Alias(ObjectAliasMixin):
         # not handled by __getattr__
         self.target[key] = value
 
+    def __len__(self) -> int:
+        return 1
+
     @property
     def kind(self) -> Kind:
         """Return the target's kind, or Kind.ALIAS if the target cannot be resolved.
@@ -749,7 +755,7 @@ class Alias(ObjectAliasMixin):
         # custom behavior to avoid raising exceptions
         try:
             return self.target.kind
-        except AliasResolutionError:
+        except (AliasResolutionError, CyclicAliasError):
             return Kind.ALIAS
 
     @property
@@ -803,6 +809,8 @@ class Alias(ObjectAliasMixin):
 
     @target.setter
     def target(self, value: Object | Alias) -> None:
+        if value is self:
+            raise CyclicAliasError([self._target_path])
         self._target = value
         if self.parent is not None:
             self._target.aliases[self.path] = self
@@ -816,11 +824,15 @@ class Alias(ObjectAliasMixin):
                 or could not be loaded (unhandled dynamic object?),
                 or when the target is from a module that was not loaded
                 and added to the collection.
+            CyclicAliasError: When the resolved target is the alias itself.
         """
         try:
-            self._target = self.modules_collection[self._target_path]
+            resolved = self.modules_collection[self._target_path]
         except KeyError as error:
             raise AliasResolutionError(self._target_path) from error
+        if resolved is self:
+            raise CyclicAliasError([self._target_path])
+        self._target = resolved
         if self.parent is not None:
             self._target.aliases[self.path] = self  # type: ignore[union-attr]  # we just set the target
 
@@ -915,7 +927,7 @@ class Module(Object):
             True or False.
         """
         try:
-            return self.filepath.name == "__init__.py"
+            return self.filepath.name.split(".", 1)[0] == "__init__"
         except BuiltinModuleError:
             return False
 
