@@ -7,6 +7,7 @@ See https://github.com/mkdocstrings/pytkdocs/pull/71.
 
 from __future__ import annotations
 
+from contextlib import suppress
 from dataclasses import dataclass, field
 from typing import TYPE_CHECKING, Any, Callable, FrozenSet
 
@@ -26,7 +27,7 @@ if TYPE_CHECKING:
 
 _warn = warning(__name__)
 
-# TODO: Examples: from the documentation, I'm not sure there is a standard format for examples
+# TODO: Examples: from the documentation, we're not sure there is a standard format for examples
 PARAM_NAMES = frozenset(("param", "parameter", "arg", "argument", "key", "keyword"))
 PARAM_TYPE_NAMES = frozenset(("type",))
 ATTRIBUTE_NAMES = frozenset(("var", "ivar", "cvar"))
@@ -242,16 +243,20 @@ def _read_attribute(docstring: Docstring, offset: int, parsed_values: ParsedValu
         _warn(docstring, 0, f"Failed to parse field directive from '{parsed_directive.line}'")
         return parsed_directive.next_index
 
-    annotation = None
+    annotation: str | Name | Expression | None = None
 
     # Annotation precedence:
     # - "vartype" directive type
+    # - annotation in the parent
     # - none
 
     parsed_attribute_type = parsed_values.attribute_types.get(name)
     if parsed_attribute_type is not None:
         annotation = parsed_attribute_type
-
+    else:
+        # try to use the annotation from the parent
+        with suppress(AttributeError, KeyError):
+            annotation = docstring.parent.attributes[name].annotation  # type: ignore[union-attr]
     if name in parsed_values.attributes:
         _warn(docstring, 0, f"Duplicate attribute entry for '{name}'")
     else:
