@@ -14,8 +14,8 @@ from __future__ import annotations
 
 import os
 import sys
-import traceback
 from contextlib import suppress
+from datetime import datetime
 from functools import lru_cache
 from pathlib import Path
 from typing import Any, Iterator, Sequence, Tuple
@@ -28,6 +28,7 @@ from griffe.dataclasses import Alias, Kind, Module, Object
 from griffe.docstrings.parsers import Parser
 from griffe.exceptions import AliasResolutionError, CyclicAliasError, UnhandledPthFileError, UnimportableModuleError
 from griffe.logger import get_logger
+from griffe.stats import stats
 
 NamePartsType = Tuple[str, ...]
 NamePartsAndPathType = Tuple[NamePartsType, Path]
@@ -36,6 +37,7 @@ logger = get_logger(__name__)
 
 _accepted_py_module_extensions = [".py", ".pyc", ".pyo", ".pyd", ".so"]
 _extensions_set = set(_accepted_py_module_extensions)
+_ignored_modules = {"debugpy", "_pydev"}
 
 # TODO: namespace packages can span multiple locations! we must support it.
 # ideally: find all locations, sort them, then reverse-merge their file lists
@@ -93,6 +95,10 @@ class GriffeLoader:
         self.docstring_options: dict[str, Any] = docstring_options or {}
         self.lines_collection: LinesCollection = lines_collection or LinesCollection()
         self.modules_collection: ModulesCollection = modules_collection or ModulesCollection()
+        self._time_stats: dict = {
+            "time_spent_visiting": 0,
+            "time_spent_inspecting": 0,
+        }
         patch_ast()
 
     def load_module(
@@ -152,19 +158,22 @@ class GriffeLoader:
             max_iterations = float("inf")  # type: ignore[assignment]
         prev_unresolved: set[str] = set()
         unresolved: set[str] = set("0")  # init to enter loop
-        iterations = 0
+        iteration = 0
         collection = self.modules_collection.members
-        while unresolved and unresolved != prev_unresolved and iterations < max_iterations:  # type: ignore[operator]
-            prev_unresolved = unresolved
+        while unresolved and unresolved != prev_unresolved and iteration < max_iterations:  # type: ignore[operator]
+            prev_unresolved = unresolved - {"0"}
             unresolved = set()
-            iterations += 1
+            resolved: set[str] = set()
+            iteration += 1
             for module_name in list(collection.keys()):
                 module = collection[module_name]
-                unresolved |= self.resolve_module_aliases(module, only_exported, only_known_modules)
-            logger.debug(f"Iteration {iterations}")
-            logger.debug(f"prev: {len(prev_unresolved)}; current: {len(unresolved)}")
-            logger.debug("\n- " + "\n- ".join(sorted(unresolved & prev_unresolved)))
-        return unresolved, iterations
+                next_resolved, next_unresolved = self.resolve_module_aliases(module, only_exported, only_known_modules)
+                resolved |= next_resolved
+                unresolved |= next_unresolved
+            logger.debug(
+                f"Iteration {iteration} finished, {len(resolved)} aliases resolved, still {len(unresolved)} to go"
+            )
+        return unresolved, iteration
 
     def resolve_module_aliases(  # noqa: WPS231
         self,
@@ -172,7 +181,7 @@ class GriffeLoader:
         only_exported: bool = True,
         only_known_modules: bool = True,
         seen: set | None = None,
-    ) -> set[str]:
+    ) -> tuple[set[str], set[str]]:
         """Follow aliases: try to recursively resolve all found aliases.
 
         Parameters:
@@ -182,8 +191,9 @@ class GriffeLoader:
             seen: Used to avoid infinite recursion.
 
         Returns:
-            True if everything was resolved, False otherwise.
+            Both sets of resolved and unresolved aliases.
         """
+        resolved = set()
         unresolved = set()
         expanded = {}
         to_remove = []
@@ -210,7 +220,7 @@ class GriffeLoader:
                 try:
                     alias = Alias(new_member.name, new_member.target)  # type: ignore[union-attr]
                 except AliasResolutionError:
-                    alias = Alias(new_member.name, new_member._target_path)  # type: ignore[union-attr]  # noqa: WPS437
+                    alias = new_member  # type: ignore[assignment]  # noqa: WPS437
                 except CyclicAliasError as error:  # noqa: WPS440
                     logger.debug(str(error))
             else:
@@ -246,10 +256,23 @@ class GriffeLoader:
                     logger.debug(str(error))
                 else:
                     logger.debug(f"Alias {member.path} was resolved to {member.target.path}")  # type: ignore[union-attr]
+                    resolved.add(member.path)
             elif member.kind in {Kind.MODULE, Kind.CLASS} and member.path not in seen:
-                unresolved |= self.resolve_module_aliases(member, only_exported, only_known_modules, seen)  # type: ignore[arg-type]
+                sub_resolved, sub_unresolved = self.resolve_module_aliases(
+                    member, only_exported, only_known_modules, seen  # type: ignore[arg-type]
+                )
+                resolved |= sub_resolved
+                unresolved |= sub_unresolved
 
-        return unresolved
+        return resolved, unresolved
+
+    def stats(self) -> dict:
+        """Compute some statistics.
+
+        Returns:
+            Some statistics.
+        """
+        return {**stats(self), **self._time_stats}
 
     def _load_module_path(
         self,
@@ -284,15 +307,14 @@ class GriffeLoader:
             member_parent[subparts[-1]] = self._load_module_path(
                 subparts[-1], subpath, submodules=False, parent=member_parent
             )
-        except SyntaxError:
-            message = traceback.format_exc(limit=0).replace("SyntaxError: invalid syntax", "").strip()
-            logger.error(f"Syntax error: {message}")
+        except SyntaxError as error:  # noqa: WPS440
+            logger.debug(f"Syntax error: {error}")
         except ImportError as error:  # noqa: WPS440
-            logger.error(f"Import error: {error}")
+            logger.debug(f"Import error: {error}")
         except UnicodeDecodeError as error:  # noqa: WPS440
-            logger.error(f"UnicodeDecodeError when loading {subpath}: {error}")
+            logger.debug(f"UnicodeDecodeError when loading {subpath}: {error}")
         except OSError as error:  # noqa: WPS440
-            logger.error(f"OSError when loading {subpath}: {error}")
+            logger.debug(f"OSError when loading {subpath}: {error}")
 
     def _create_module(self, module_name: str, module_path: Path) -> Module:
         return Module(
@@ -304,7 +326,8 @@ class GriffeLoader:
 
     def _visit_module(self, code: str, module_name: str, module_path: Path, parent: Module | None = None) -> Module:
         self.lines_collection[module_path] = code.splitlines(keepends=False)
-        return visit(
+        start = datetime.now()
+        module = visit(
             module_name,
             filepath=module_path,
             code=code,
@@ -315,10 +338,17 @@ class GriffeLoader:
             lines_collection=self.lines_collection,
             modules_collection=self.modules_collection,
         )
+        elapsed = datetime.now() - start
+        self._time_stats["time_spent_visiting"] += elapsed.microseconds
+        return module
 
     def _inspect_module(self, module_name: str, filepath: Path | None = None, parent: Module | None = None) -> Module:
+        for prefix in _ignored_modules:
+            if module_name.startswith(prefix):
+                raise ImportError(f"Ignored module '{module_name}'")
+        start = datetime.now()
         try:
-            return inspect(
+            module = inspect(
                 module_name,
                 filepath=filepath,
                 extensions=self.extensions,
@@ -329,6 +359,9 @@ class GriffeLoader:
             )
         except SystemExit as error:
             raise ImportError(f"Importing '{module_name}' raised a system exit") from error
+        elapsed = datetime.now() - start
+        self._time_stats["time_spent_inspecting"] += elapsed.microseconds
+        return module
 
     def _member_parent(self, module: Module, subparts: NamePartsType, subpath: Path) -> Module:
         parent_parts = subparts[:-1]
